package token

import (
	"birdcall/internal/consts"
	"birdcall/internal/library/birdeye"
	"birdcall/internal/model/birdeye/token"
	"encoding/json"
	"net/http"
	"net/url"
	"os"
	"strconv"
)

type Token struct{}

// GetListV1
//
//	@param chain_name
//	@param sort_by
//	@param sort_type
//	@param offset
//	@param limit
//	@param min_liquidity
//	@return *token.ListRes
//	@return error
func (t *Token) GetListV1(chain_name string, sort_by string, sort_type string, offset uint64, limit uint64, min_liquidity uint64) (*token.ListRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(consts.TOKEN_URL)
	params := url.Values{}
	params.Add(consts.SORT_BY, sort_by)
	params.Add(consts.SORT_TYPE, sort_type)
	params.Add(consts.OFFSET, strconv.FormatUint(offset, 10))
	params.Add(consts.LIMIT, strconv.FormatUint(limit, 10))
	params.Add(consts.MIN_LIQUIDITY, strconv.FormatUint(min_liquidity, 10))

	fullURL := baseURL + consts.TOKEN_LIST + consts.QUESTION_MARK + params.Encode()
	apiReq, err := http.NewRequest(consts.GET, fullURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq, chain_name)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}

	//处理返回数据
	var res *token.ListRes
	err = json.Unmarshal([]byte(body), &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}

func (t *Token) GetListV2(chain_name string) (*token.ListRes, error) {
	//构建基本请求连接
	baseURL := os.Getenv(consts.TOKEN_LIST_V2_URL)

	apiReq, err := http.NewRequest(consts.POST, baseURL, nil)
	if err != nil {
		return nil, err
	}
	//构建请求头
	apiReq = birdeye.MakeHeader(apiReq, chain_name)

	body, err := birdeye.SendRequest(apiReq)
	if err != nil {
		return nil, err
	}
	//处理返回数据
	var res *token.ListRes
	err = json.Unmarshal([]byte(body), &res)
	if err != nil {
		return nil, err
	}
	return res, nil
}
